<template>
	<div :style='widgetWrapperStyle'>
		<div :style='{...widgetStyle, ...transitionStyle}'>
            <a class='image-card-wrapper' :href='link ? link : null' target="_blank" rel="noopener noreferrer" :style='{width: size + "em"}'>
				<div class='background'>
                    <img :src='image_src'>
                    <div class='fade' v-if='caption'></div>
                </div>

				<div class='dim' v-if='caption'></div>

				<div class="image-card">
					<div class="image-card__caption" v-html="caption"/>
				</div>
			</a>
		</div>
	</div>
</template>

<script>
import {positionMixin} from '../helpers/widgets.mjs'

export default {
	mixins: [positionMixin],

	props: {
		caption: {
			type: String,
			default: 'Товар',
		},
		link: {
			type: String,
			default: '',
		},
		image_src: {
			type: String,
			default: '',
		},
		size: {
			type: Number,
			default: 12,
		},
	},

	data() {
		return {}
	},

	computed: {
		formatPrice() {
			return this.price
		},
	},

	methods: {},
}
</script>

<style scoped>

a:not([href]) {
    cursor: default;
}

.image-card-wrapper {
	overflow: hidden;
	position: relative;
    display: block;

	border-radius: .7em;
	font-family: var(--primary-font);

	pointer-events: all;
}

.background {
	width: 100%;
	transition: transform .2s ease;
}

.fade {
    position: absolute;
    left: 0;
    top: 0;
    right: 0;
    bottom: 0;

	background: linear-gradient(0deg, rgba(0, 0, 0, 0.5) 0, rgba(0, 0, 0, 0) 3em);
}

.background img {
    width: 100%;
}

.image-card {
	position: absolute;
    bottom: .5em;
    left: .6em;

	display: flex;
	flex-direction: column;
	justify-content: flex-end;
	gap: .5em;

	color: white;
	font-variation-settings: 'wght' 300;

	text-decoration: none;
	font-size: .8em;
	line-height: 1.2;
}

.dim {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;

	background: black;
	opacity: 0.1;
	transition: opacity .2s ease;
}

.image-card-wrapper:hover .background {
	transform: scale(1.05)
}

.image-card-wrapper:hover .dim {
	opacity: 0;
}


.image-card__price {
	font-variation-settings: 'wght' 500;
	transition: color .2s ease;
}

.image-card__caption {
	transition: color .2s ease;
}

.image-card-wrapper .image-card__price img {
	height: 1em;
	vertical-align: baseline;
}

</style>
